@@ -366,6 +366,17 @@ export const globalSettings = {
             },
           },
         },
+        labRequest: {
+          description: 'Lab request settings',
+          properties: {
+            enableLabResultsPrintout: {
+              name: "Lab results printout",
+              description: 'Enable lab results printout (print results button and interim report option)',
+              type: yup.boolean(),
+              defaultValue: true,
+            },
+          },
+        },
       },
     },
     customisations: {
@@ -1244,8 +1255,35 @@ export const globalSettings = {
       },
     },
     security: {
+      highRisk: true,
       description: 'Security settings',
       properties: {
+        reportNoUserError: {
+          description:
+            'Display "no such user" message when authenticating. This may weaken security by allowing attackers to determine valid usernames.',
+          type: yup.boolean(),
+          defaultValue: false,
+        },
+        loginAttempts: {
+          description: 'Login attempts settings',
+          properties: {
+            lockoutThreshold: {
+              description: 'Number of failed attempts before account is locked',
+              type: yup.number().positive().integer(),
+              defaultValue: 10,
+            },
+            observationWindow: {
+              description: 'Time interval in minutes that attempts must occur within',
+              type: yup.number().positive().integer(),
+              defaultValue: 10,
+            },
+            lockoutDuration: {
+              description: 'Duration of lockout in minutes',
+              type: yup.number().positive(),
+              defaultValue: 10,
+            },
+          },
+        },
         mobile: {
           description: 'Mobile security settings',
           properties: {
